==> nextcloud-18.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/user_ldap/l10n/ro.js <==
OC.L10N.register(
    "user_ldap",
    {
    "Failed to clear the mappings." : "Ștergerea mapărilor a eșuat.",
    "Failed to delete the server configuration" : "Ștergerea configurației serverului a eșuat.",
    "Valid configuration, connection established!" : "Configurație validată, conexiune stabilită!",
    "No action specified" : "Nu este specificată nicio acțiune ",
    "No configuration specified" : "Nu este specificată nicio configurație",
    "No data specified" : "Nu au fost specificate date",
    " Could not set configuration %s" : "Nu a putut fi setată configurația %s",
    "Action does not exist" : "Acțiunea nu există",
    "Renewing …" : "Reînnoiesc ...",
    "Very weak password" : "Parolă foarte slabă",
    "Weak password" : "Parolă slabă",
    "So-so password" : "Parolă medie",
    "Good password" : "Parolă bună",
    "Strong password" : "Parolă puternică",
    "The Base DN appears to be wrong" : "DN-ul de bază pare a fi greșit",
    "Testing configuration…" : "Se testează configurația...",
    "Configuration incorrect" : "Configurație incorectă",
    "Configuration incomplete" : "Configurație incompletă",
    "Configuration OK" : "Configurație validă",
    "Select groups" : "Selectează grupuri ",
    "Select object classes" : "Selectează clase de obiecte",
    "Please check the credentials, they seem to be wrong." : "Verifică datele de autentificare, ele par a fi greșite.",
    "Please specify the port, it could not be auto-detected." : "Specifică portul, nu a putut fi detectat automat.",
    "Base DN could not be auto-detected, please revise credentials, host and port." : "DN-ul de bază nu a putut fi detectat automat, te rugăm revizuiește datele de autentificare, gazda și portul.",
    "Could not detect Base DN, please enter it manually." : "DN-ul de bază nu a putut fi detectat, introdu-l manual.",
    "{nthServer}. Server" : "{nthServer}. Server",
    "More than 1,000 directory entries available." : "Mai mult de 1000 de directoare disponibile.",
    "Do you really want to delete the current Server Configuration?" : "Sigur vrei să ștergi configurația curentă a serverului?",
    "Confirm Deletion" : "Confirmă ștergerea",
    "Mappings cleared successfully!" : "Asocierile au fost șterse!",
    "Error while clearing the mappings." : "Eroare la ștergerea asocierilor.",
    "Select attributes" : "Selectaţi caracteristici",
    "Your password will expire tomorrow." : "Parola ta va expira mâine.",
    "Your password will expire today." : "Parola ta va expira astăzi.",
    "_Your password will expire within %n day._::_Your password will expire within %n days._" : ["Parola ta va expira în %n zi.","Parola ta va expira în %n zile.","Parola ta va expira în %n zile."],
    "LDAP / AD integration" : "Integrare LDAP / AD",
    "_%s group found_::_%s groups found_" : ["%s grup găsit.","%s grupuri găsite.","%s grupuri găsite."],
    "_%s user found_::_%s users found_" : ["%s utilizator găsit.","%s utilizatori găsiți.","%s utilizatori găsiți."],
    "Could not find the desired feature" : "Nu s-a putut găsi funcționalitatea dorită.",
    "Invalid Host" : "Host invalid",
    "Test Configuration" : "Configurare test",
    "Help" : "Ajutor",
    "Search groups" : "Caută grupuri",
    "Available groups" : "Grupuri disponibile",
    "Selected groups" : "Grupurile selectate",
    "LDAP Filter:" : "Filtru LDAP:",
    "LDAP / AD Username:" : "Utilizator LDAP / AD",
    "Other Attributes:" : "Alte caracteristici :",
    "Verify settings" : "Verifică setările",
    "%s. Server:" : "%s. Server:",
    "Delete the current configuration" : "Șterge configurația curentă",
    "Host" : "Gazdă",
    "Port" : "Portul",
    "Detect Port" : "Detectează portul",
    "User DN" : "DN-ul utilizatorului",
    "The DN of the client user with which the bind shall be done, e.g. uid=agent,dc=example,dc=com. For anonymous access, leave DN and Password empty." : "DN-ul utilizatorului cu care se va efectua asocierea, de exemplu uid=agent,dc=example,dc=com. Pentru acces anonim, lasă DN-ul și parola libere.",
    "Password" : "Parolă",
    "For anonymous access, leave DN and Password empty." : "Pentru acces anonim, lasă DN-ul și parola libere.",
    "Save Credentials" : "Salvează datele de autentificare",
    "One Base DN per line" : "Un DN de bază pe linie",
    "You can specify Base DN for users and groups in the Advanced tab" : "Poți specifica DN-ul de bază pentru utilizatori și grupuri în fila Avansat",
    "Detect Base DN" : "Detectează DN-ul de bază",
    "Test Base DN" : "Testează DN-ul de bază",
    "Avoids automatic LDAP requests. Better for bigger setups, but requires some LDAP knowledge." : "Evită solicitările LDAP automate. De preferat pentru instalările mai complexe, dar necesită câteva cunoștințe LDAP.",
    "Manually enter LDAP filters (recommended for large directories)" : "Introdu filtrele LDAP manual (recomandat pentru medii LDAP largi)",
    "Verify settings and count users" : "Verifică setările și numără utilizatorii",
    "Saving" : "Se salvează",
    "Back" : "Înapoi",
    "Continue" : "Continuă",
    "Please renew your password." : "Te rog reînnoiește parola.",
    "An internal error occurred." : "A apărut o eroare internă.",
    "Please try again or contact your administrator." : "Încearcă din nou sau contactează-ți administratorul.",
    "Current password" : "Parola curentă",
    "New password" : "Noua parolă",
    "Renew password" : "Reînnoiește parola",
    "Wrong password." : "Parolă greșită.",
    "Cancel" : "Anulează",
    "Server" : "Server",
    "Users" : "Utilizatori",
    "Login Attributes" : "Atribute de autentificare",
    "Groups" : "Grupuri",
    "Expert" : "Expert",
    "Advanced" : "Avansat",
    "<b>Warning:</b> The PHP LDAP module is not installed, the backend will not work. Please ask your system administrator to install it." : "<b>Atenție</b> Modulul PHP LDAP nu este instalat, infrastructura nu va funcționa. Contactează administratorul sistemului pentru al instala.",
    "Connection Settings" : "Setările de conexiune",
    "Configuration Active" : "Configurație activă",
    "When unchecked, this configuration will be skipped." : "Dacă este debifat, se va sări peste această configurație.",
    "Disable Main Server" : "Dezactivaţi serverul principal",
    "Turn off SSL certificate validation." : "Oprește validarea certificatelor SSL ",
    "in seconds. A change empties the cache." : "în secunde. O schimbare curăță memoria tampon.",
    "Directory Settings" : "Setările directorului",
    "User Display Name Field" : "Câmpul cu numele vizibil al utilizatorului",
    "Base User Tree" : "Arborele de bază al utilizatorilor",
    "One User Base DN per line" : "Un DN utilizator de bază pe linie",
    "Group Display Name Field" : "Câmpul cu numele grupului",
    "Base Group Tree" : "Arborele de bază al Grupurilor",
    "One Group Base DN per line" : "Un Group Base DN pe linie",
    "Group-Member association" : "Asocierea Grup-Membru",
    "Special Attributes" : "Caracteristici speciale ",
    "Leave empty for user name (default). Otherwise, specify an LDAP/AD attribute." : "Lăsați gol pentru numele de utilizator (implicit). În caz contrar, specificați un atribut LDAP / AD.",
    "Internal Username" : "Nume utilizator intern"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> nextcloud-20.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/user_ldap/l10n/ro.js <==
OC.L10N.register(
    "user_ldap",
    {
    "Failed to clear the mappings." : "Ștergerea mapărilor a eșuat.",
    "Failed to delete the server configuration" : "Ștergerea configurației serverului a eșuat.",
    "Valid configuration, connection established!" : "Configurație validată, conexiune stabilită!",
    "No action specified" : "Nu este specificată nicio acțiune ",
    "No configuration specified" : "Nu este specificată nicio configurație",
    "No data specified" : "Nu au fost specificate date",
    " Could not set configuration %s" : "Nu a putut fi setată configurația %s",
    "Action does not exist" : "Acțiunea nu există",
    "Renewing …" : "Reînnoiesc ...",
    "Very weak password" : "Parolă foarte slabă",
    "Weak password" : "Parolă slabă",
    "So-so password" : "Parolă medie",
    "Good password" : "Parolă bună",
    "Strong password" : "Parolă puternică",
    "The Base DN appears to be wrong" : "DN-ul de bază pare a fi greșit",
    "Testing configuration…" : "Se testează configurația...",
    "Configuration incorrect" : "Configurație incorectă",
    "Configuration incomplete" : "Configurație incompletă",
    "Configuration OK" : "Configurație validă",
    "Select groups" : "Selectează grupuri ",
    "Select object classes" : "Selectează clase de obiecte",
    "Please check the credentials, they seem to be wrong." : "Verifică datele de autentificare, ele par a fi greșite.",
    "Please specify the port, it could not be auto-detected." : "Specifică portul, nu a putut fi detectat automat.",
    "Base DN could not be auto-detected, please revise credentials, host and port." : "DN-ul de bază nu a putut fi detectat automat, te rugăm revizuiește datele de autentificare, gazda și portul.",
    "Could not detect Base DN, please enter it manually." : "DN-ul de bază nu a putut fi detectat, introdu-l manual.",
    "{nthServer}. Server" : "{nthServer}. Server",
    "More than 1,000 directory entries available." : "Mai mult de 1000 de directoare disponibile.",
    "Do you really want to delete the current Server Configuration?" : "Sigur vrei să ștergi configurația curentă a serverului?",
    "Confirm Deletion" : "Confirmă ștergerea",
    "Mappings cleared successfully!" : "Asocierile au fost șterse!",
    "Error while clearing the mappings." : "Eroare la ștergerea asocierilor.",
    "Select attributes" : "Selectaţi caracteristici",
    "Your password will expire tomorrow." : "Parola ta va expira mâine.",
    "Your password will expire today." : "Parola ta va expira astăzi.",
    "_Your password will expire within %n day._::_Your password will expire within %n days._" : ["Parola ta va expira în %n zi.","Parola ta va expira în %n zile.","Parola ta va expira în %n zile."],
    "LDAP / AD integration" : "Integrare LDAP / AD",
    "_%s group found_::_%s groups found_" : ["%s grup găsit.","%s grupuri găsite.","%s grupuri găsite."],
    "_%s user found_::_%s users found_" : ["%s utilizator găsit.","%s utilizatori găsiți.","%s utilizatori găsiți."],
    "Could not find the desired feature" : "Nu s-a putut găsi funcționalitatea dorită.",
    "Invalid Host" : "Host invalid",
    "Test Configuration" : "Configurare test",
    "Help" : "Ajutor",
    "Search groups" : "Caută grupuri",
    "Available groups" : "Grupuri disponibile",
    "Selected groups" : "Grupurile selectate",
    "LDAP Filter:" : "Filtru LDAP:",
    "LDAP / AD Username:" : "Utilizator LDAP / AD",
    "Other Attributes:" : "Alte caracteristici :",
    "Verify settings" : "Verifică setările",
    "%s. Server:" : "%s. Server:",
    "Delete the current configuration" : "Șterge configurația curentă",
    "Host" : "Gazdă",
    "Port" : "Portul",
    "Detect Port" : "Detectează portul",
    "User DN" : "DN-ul utilizatorului",
    "The DN of the client user with which the bind shall be done, e.g. uid=agent,dc=example,dc=com. For anonymous access, leave DN and Password empty." : "DN-ul utilizatorului cu care se va efectua asocierea, de exemplu uid=agent,dc=example,dc=com. Pentru acces anonim, lasă DN-ul și parola libere.",
    "Password" : "Parolă",
    "For anonymous access, leave DN and Password empty." : "Pentru acces anonim, lasă DN-ul și parola libere.",
    "Save Credentials" : "Salvează datele de autentificare",
    "One Base DN per line" : "Un DN de bază pe linie",
    "You can specify Base DN for users and groups in the Advanced tab" : "Poți specifica DN-ul de bază pentru utilizatori și grupuri în fila Avansat",
    "Detect Base DN" : "Detectează DN-ul de bază",
    "Test Base DN" : "Testează DN-ul de bază",
    "Avoids automatic LDAP requests. Better for bigger setups, but requires some LDAP knowledge." : "Evită solicitările LDAP automate. De preferat pentru instalările mai complexe, dar necesită câteva cunoștințe LDAP.",
    "Manually enter LDAP filters (recommended for large directories)" : "Introdu filtrele LDAP manual (recomandat pentru medii LDAP largi)",
    "Verify settings and count users" : "Verifică setările și numără utilizatorii",
    "Saving" : "Se salvează",
    "Back" : "Înapoi",
    "Continue" : "Continuă",
    "Please renew your password." : "Te rog reînnoiește parola.",
    "An internal error occurred." : "A apărut o eroare internă.",
    "Please try again or contact your administrator." : "Încearcă din nou sau contactează-ți administratorul.",
    "Current password" : "Parola curentă",
    "New password" : "Noua parolă",
    "Renew password" : "Reînnoiește parola",
    "Wrong password." : "Parolă greșită.",
    "Cancel" : "Anulează",
    "Server" : "Server",
    "Users" : "Utilizatori",
    "Login Attributes" : "Atribute de autentificare",
    "Groups" : "Grupuri",
    "Expert" : "Expert",
    "Advanced" : "Avansat",
    "<b>Warning:</b> The PHP LDAP module is not installed, the backend will not work. Please ask your system administrator to install it." : "<b>Atenție</b> Modulul PHP LDAP nu este instalat, infrastructura nu va funcționa. Contactează administratorul sistemului pentru al instala.",
    "Connection Settings" : "Setările de conexiune",
    "Configuration Active" : "Configurație activă",
    "When unchecked, this configuration will be skipped." : "Dacă este debifat, se va sări peste această configurație.",
    "Disable Main Server" : "Dezactivaţi serverul principal",
    "Turn off SSL certificate validation." : "Oprește validarea certificatelor SSL ",
    "in seconds. A change empties the cache." : "în secunde. O schimbare curăță memoria tampon.",
    "Directory Settings" : "Setările directorului",
    "User Display Name Field" : "Câmpul cu numele vizibil al utilizatorului",
    "Base User Tree" : "Arborele de bază al utilizatorilor",
    "One User Base DN per line" : "Un DN utilizator de bază pe linie",
    "Group Display Name Field" : "Câmpul cu numele grupului",
    "Base Group Tree" : "Arborele de bază al Grupurilor",
    "One Group Base DN per line" : "Un Group Base DN pe linie",
    "Group-Member association" : "Asocierea Grup-Membru",
    "Special Attributes" : "Caracteristici speciale ",
    "Internal Username" : "Nume utilizator intern",
    "Leave empty for user name (default). Otherwise, specify an LDAP/AD attribute." : "Lăsați gol pentru numele de utilizator (implicit). În caz contrar, specificați un atribut LDAP / AD."
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
